==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Przywracanie systemu, proszę czekać...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Przywracanie nie powiodło się.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Błąd aktualizacji.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Błąd aktualizacji: została przerwana.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Błąd aktualizacji: DPKG error.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Błąd aktualizacji: za mało miejsca na dysku.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Czy na pewno chcesz przywrócić do %1 z dnia %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Anuluj i uruchom ponownie</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.21.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Przywracanie systemu, proszę czekać...</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Przywracanie nie powiodło się.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Błąd aktualizacji.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Błąd aktualizacji: została przerwana.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Błąd aktualizacji: DPKG error.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Błąd aktualizacji: za mało miejsca na dysku.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Czy na pewno chcesz przywrócić do %1 z dnia %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Anuluj i uruchom ponownie</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
</TS>
